@@ -5,11 +5,8 @@ a = pybles.Pyble(header_color='STRONG_RED', header_background_color='BG_WHITE')
 a.add_column('First Name')
 a.add_column('Last Name')
 a.add_line(['John', 'Doe'])
-a.add_line(['A', 'B'])
-a.add_line(['A', 'B'])
-a.add_line(['A', 'B'])
 a.show_table()
-
 a.set_color(True)
-
 a.show_table()
+
+print a.get_table_as_json()
